@@ -14,7 +14,7 @@ from pulpcore.plugin.models import (
     TaskGroup,
 )
 
-from pulpcore.plugin.tasking import enqueue_with_reservation
+from pulpcore.plugin.tasking import dispatch
 
 from pulp_2to3_migration.app.models import (
     Pulp2Content,
@@ -284,7 +284,7 @@ def create_repoversions_publications_distributions(plan, parallel=True):
                     repo_ver_to_create += len(repo_versions)
                     repo = Repository.objects.get(name=repo_name).cast()
                     task_args = [plugin, pulp3_repo_setup, repo_name]
-                    enqueue_with_reservation(
+                    dispatch(
                         complex_repo_migration,
                         [repo],
                         args=task_args,
@@ -415,9 +415,7 @@ def create_repo_version(progress_rv, pulp2_repo, pulp3_remote=None):
             else:
                 # It's not a duplicated path but it overlaps with some other in the version,
                 # it should be removed from the version to resolve the conflict.
-                version.remove_content(
-                    Content.objects.filter(pk__in=cas_with_conflicts[0].content.pk)
-                )
+                version.remove_content(cas_with_conflicts[0].content)
                 _logger.info(
                     _(
                         'Overlapping paths have been found in Pulp 3 repo `{repo}`: Removed '
@@ -427,15 +425,18 @@ def create_repo_version(progress_rv, pulp2_repo, pulp3_remote=None):
                 # exclude the resolved path from further search
                 paths.remove(bad_path)
 
+    pulp3_repo = pulp2_repo.pulp3_repository
     if pulp3_remote:
         pulp2_repo.pulp3_repository_remote = pulp3_remote
         pulp2_repo.save()
 
+        pulp3_repo.remote = pulp3_remote
+        pulp3_repo.save()
+
     if pulp2_repo.is_migrated:
         progress_rv.update(total=F('total') - 1)
         return
 
-    pulp3_repo = pulp2_repo.pulp3_repository
     unit_ids = Pulp2RepoContent.objects.filter(pulp2_repository=pulp2_repo).values_list(
         'pulp2_unit_id', flat=True)
     incoming_content = set(
