@@ -12,7 +12,7 @@ from mongoengine.queryset.visitor import Q as mongo_Q
 
 from pulpcore.plugin.constants import TASK_STATES
 from pulpcore.plugin.models import (
-    BaseDistribution,
+    Distribution,
     Publication,
     ProgressReport,
 )
@@ -296,9 +296,8 @@ def pre_migrate_content_type(content_model, mutable_type, lazy_type, premigrate_
 
         mongo_content_qs = content_model.pulp2.objects(
             id__in=content_relations.values_list('pulp2_unit_id', flat=True))
-        batched_mongo_content_qs = mongo_content_qs.only(*mongo_fields).batch_size(batch_size)
         pulp2_content_by_id = {
-            record.id: record for record in batched_mongo_content_qs.no_cache()
+            record.id: record for record in mongo_content_qs.only(*mongo_fields).no_cache()
         }
 
         for relation in content_relations:
@@ -605,8 +604,7 @@ def pre_migrate_importer(repo_id, importer_types):
         if last_updated != importer.pulp2_last_updated:
             # remove Remote in case of feed change
             if importer.pulp2_config.get('feed') != importer_data.config.get('feed'):
-                if importer.pulp3_remote:
-                    importer.pulp3_remote.delete()
+                importer.pulp3_remote.delete()
                 importer.pulp3_remote = None
                 # do not flip is_migrated to False for LCE for at least once migrated importer
 
@@ -801,7 +799,7 @@ def handle_outdated_resources(plan):
             pulp2distributor__in=pulp2distributors_with_old_distributions_qs).delete()
 
         # Delete outdated distributions
-        BaseDistribution.objects.filter(
+        Distribution.objects.filter(
             pulp2distributor__in=pulp2distributors_with_old_distributions_qs).delete()
 
         # Remove relations to the pulp2repository in case the relation changed.
